``eradiate.util``
=================

.. automodule:: eradiate.util

``eradiate.util.deprecation``
-----------------------------

.. automodule:: eradiate.util.deprecation
   :members:
   :member-order: bysource

``eradiate.util.misc``
----------------------

.. automodule:: eradiate.util.misc
   :members:

``eradiate.util.numpydoc``
--------------------------

.. automodule:: eradiate.util.numpydoc
   :members:
